@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 2.5.  */
 
 /* Bison interface for Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
-
+   
+      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
+   
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,21 +26,14 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_MAIN_LIB_CFG_GRAMMAR_H_INCLUDED
-# define YY_MAIN_LIB_CFG_GRAMMAR_H_INCLUDED
-/* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
-#if YYDEBUG
-extern int main_debug;
-#endif
 /* "%code requires" blocks.  */
-#line 25 "../lib/cfg-grammar.y" /* yacc.c:1909  */
+
+/* Line 2068 of yacc.c  */
+#line 25 "cfg-grammar.y"
 
 
 /* this block is inserted into cfg-grammar.h, so it is included
@@ -56,6 +49,8 @@ extern int main_debug;
 #include "filter/filter-pipe.h"
 #include "parser/parser-expr-parser.h"
 #include "rewrite/rewrite-expr-parser.h"
+#include "logmatcher.h"
+#include "logthrdestdrv.h"
 
 /* uses struct declarations instead of the typedefs to avoid having to
  * include logreader/logwriter/driver.h, which defines the typedefs.  This
@@ -74,158 +69,169 @@ extern struct _LogTemplateOptions *last_template_options;
 extern struct _LogTemplate *last_template;
 extern struct _ValuePairs *last_value_pairs;
 extern struct _ValuePairsTransformSet *last_vp_transset;
+extern struct _LogMatcherOptions *last_matcher_options;
+extern struct _HostResolveOptions *last_host_resolve_options;
+extern struct _StatsOptions *last_stats_options;
 
 
-#line 80 "lib/cfg-grammar.h" /* yacc.c:1909  */
 
-/* Token type.  */
+
+/* Line 2068 of yacc.c  */
+#line 81 "lib/cfg-grammar.h"
+
+/* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-  enum yytokentype
-  {
-    LL_CONTEXT_ROOT = 1,
-    LL_CONTEXT_DESTINATION = 2,
-    LL_CONTEXT_SOURCE = 3,
-    LL_CONTEXT_PARSER = 4,
-    LL_CONTEXT_REWRITE = 5,
-    LL_CONTEXT_FILTER = 6,
-    LL_CONTEXT_LOG = 7,
-    LL_CONTEXT_BLOCK_DEF = 8,
-    LL_CONTEXT_BLOCK_REF = 9,
-    LL_CONTEXT_BLOCK_CONTENT = 10,
-    LL_CONTEXT_BLOCK_ARG = 11,
-    LL_CONTEXT_PRAGMA = 12,
-    LL_CONTEXT_FORMAT = 13,
-    LL_CONTEXT_TEMPLATE_FUNC = 14,
-    LL_CONTEXT_INNER_DEST = 15,
-    LL_CONTEXT_INNER_SRC = 16,
-    LL_CONTEXT_CLIENT_PROTO = 17,
-    LL_CONTEXT_SERVER_PROTO = 18,
-    KW_SOURCE = 10000,
-    KW_FILTER = 10001,
-    KW_PARSER = 10002,
-    KW_DESTINATION = 10003,
-    KW_LOG = 10004,
-    KW_OPTIONS = 10005,
-    KW_INCLUDE = 10006,
-    KW_BLOCK = 10007,
-    KW_JUNCTION = 10008,
-    KW_CHANNEL = 10009,
-    KW_INTERNAL = 10010,
-    KW_FILE = 10011,
-    KW_SQL = 10030,
-    KW_TYPE = 10031,
-    KW_COLUMNS = 10032,
-    KW_INDEXES = 10033,
-    KW_VALUES = 10034,
-    KW_PASSWORD = 10035,
-    KW_DATABASE = 10036,
-    KW_USERNAME = 10037,
-    KW_TABLE = 10038,
-    KW_ENCODING = 10039,
-    KW_SESSION_STATEMENTS = 10040,
-    KW_DELIMITERS = 10050,
-    KW_QUOTES = 10051,
-    KW_QUOTE_PAIRS = 10052,
-    KW_NULL = 10053,
-    KW_SYSLOG = 10060,
-    KW_MARK_FREQ = 10071,
-    KW_STATS_FREQ = 10072,
-    KW_STATS_LEVEL = 10073,
-    KW_FLUSH_LINES = 10074,
-    KW_SUPPRESS = 10075,
-    KW_FLUSH_TIMEOUT = 10076,
-    KW_LOG_MSG_SIZE = 10077,
-    KW_FILE_TEMPLATE = 10078,
-    KW_PROTO_TEMPLATE = 10079,
-    KW_MARK_MODE = 10080,
-    KW_CHAIN_HOSTNAMES = 10090,
-    KW_NORMALIZE_HOSTNAMES = 10091,
-    KW_KEEP_HOSTNAME = 10092,
-    KW_CHECK_HOSTNAME = 10093,
-    KW_BAD_HOSTNAME = 10094,
-    KW_KEEP_TIMESTAMP = 10100,
-    KW_USE_DNS = 10110,
-    KW_USE_FQDN = 10111,
-    KW_DNS_CACHE = 10120,
-    KW_DNS_CACHE_SIZE = 10121,
-    KW_DNS_CACHE_EXPIRE = 10130,
-    KW_DNS_CACHE_EXPIRE_FAILED = 10131,
-    KW_DNS_CACHE_HOSTS = 10132,
-    KW_PERSIST_ONLY = 10140,
-    KW_TZ_CONVERT = 10150,
-    KW_TS_FORMAT = 10151,
-    KW_FRAC_DIGITS = 10152,
-    KW_LOG_FIFO_SIZE = 10160,
-    KW_LOG_FETCH_LIMIT = 10162,
-    KW_LOG_IW_SIZE = 10163,
-    KW_LOG_PREFIX = 10164,
-    KW_PROGRAM_OVERRIDE = 10165,
-    KW_HOST_OVERRIDE = 10166,
-    KW_THROTTLE = 10170,
-    KW_THREADED = 10171,
-    KW_FLAGS = 10190,
-    KW_PAD_SIZE = 10200,
-    KW_TIME_ZONE = 10201,
-    KW_RECV_TIME_ZONE = 10202,
-    KW_SEND_TIME_ZONE = 10203,
-    KW_LOCAL_TIME_ZONE = 10204,
-    KW_FORMAT = 10205,
-    KW_TIME_REOPEN = 10210,
-    KW_TIME_REAP = 10211,
-    KW_TIME_SLEEP = 10212,
-    KW_TMPL_ESCAPE = 10220,
-    KW_OPTIONAL = 10230,
-    KW_CREATE_DIRS = 10240,
-    KW_OWNER = 10250,
-    KW_GROUP = 10251,
-    KW_PERM = 10252,
-    KW_DIR_OWNER = 10260,
-    KW_DIR_GROUP = 10261,
-    KW_DIR_PERM = 10262,
-    KW_TEMPLATE = 10270,
-    KW_TEMPLATE_ESCAPE = 10271,
-    KW_DEFAULT_FACILITY = 10300,
-    KW_DEFAULT_LEVEL = 10301,
-    KW_PORT = 10323,
-    KW_USE_TIME_RECVD = 10340,
-    KW_FACILITY = 10350,
-    KW_LEVEL = 10351,
-    KW_HOST = 10352,
-    KW_MATCH = 10353,
-    KW_MESSAGE = 10354,
-    KW_NETMASK = 10355,
-    KW_TAGS = 10356,
-    KW_VALUE = 10361,
-    KW_REWRITE = 10370,
-    KW_SET = 10371,
-    KW_SUBST = 10372,
-    KW_YES = 10380,
-    KW_NO = 10381,
-    KW_IFDEF = 10410,
-    KW_ENDIF = 10411,
-    LL_DOTDOT = 10420,
-    LL_IDENTIFIER = 10421,
-    LL_NUMBER = 10422,
-    LL_FLOAT = 10423,
-    LL_STRING = 10424,
-    LL_TOKEN = 10425,
-    LL_BLOCK = 10426,
-    LL_PRAGMA = 10427,
-    LL_EOL = 10428,
-    LL_ERROR = 10429,
-    KW_VALUE_PAIRS = 10500,
-    KW_SELECT = 10501,
-    KW_EXCLUDE = 10502,
-    KW_PAIR = 10503,
-    KW_KEY = 10504,
-    KW_SCOPE = 10505,
-    KW_SHIFT = 10506,
-    KW_REKEY = 10507,
-    KW_ADD_PREFIX = 10508,
-    KW_REPLACE_PREFIX = 10509,
-    KW_ON_ERROR = 10510
-  };
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     LL_CONTEXT_ROOT = 1,
+     LL_CONTEXT_DESTINATION = 2,
+     LL_CONTEXT_SOURCE = 3,
+     LL_CONTEXT_PARSER = 4,
+     LL_CONTEXT_REWRITE = 5,
+     LL_CONTEXT_FILTER = 6,
+     LL_CONTEXT_LOG = 7,
+     LL_CONTEXT_BLOCK_DEF = 8,
+     LL_CONTEXT_BLOCK_REF = 9,
+     LL_CONTEXT_BLOCK_CONTENT = 10,
+     LL_CONTEXT_BLOCK_ARG = 11,
+     LL_CONTEXT_PRAGMA = 12,
+     LL_CONTEXT_FORMAT = 13,
+     LL_CONTEXT_TEMPLATE_FUNC = 14,
+     LL_CONTEXT_INNER_DEST = 15,
+     LL_CONTEXT_INNER_SRC = 16,
+     LL_CONTEXT_CLIENT_PROTO = 17,
+     LL_CONTEXT_SERVER_PROTO = 18,
+     KW_SOURCE = 10000,
+     KW_FILTER = 10001,
+     KW_PARSER = 10002,
+     KW_DESTINATION = 10003,
+     KW_LOG = 10004,
+     KW_OPTIONS = 10005,
+     KW_INCLUDE = 10006,
+     KW_BLOCK = 10007,
+     KW_JUNCTION = 10008,
+     KW_CHANNEL = 10009,
+     KW_INTERNAL = 10010,
+     KW_FILE = 10011,
+     KW_SQL = 10030,
+     KW_TYPE = 10031,
+     KW_COLUMNS = 10032,
+     KW_INDEXES = 10033,
+     KW_VALUES = 10034,
+     KW_PASSWORD = 10035,
+     KW_DATABASE = 10036,
+     KW_USERNAME = 10037,
+     KW_TABLE = 10038,
+     KW_ENCODING = 10039,
+     KW_SESSION_STATEMENTS = 10040,
+     KW_DELIMITERS = 10050,
+     KW_QUOTES = 10051,
+     KW_QUOTE_PAIRS = 10052,
+     KW_NULL = 10053,
+     KW_SYSLOG = 10060,
+     KW_MARK_FREQ = 10071,
+     KW_STATS_FREQ = 10072,
+     KW_STATS_LEVEL = 10073,
+     KW_STATS_LIFETIME = 10074,
+     KW_FLUSH_LINES = 10075,
+     KW_SUPPRESS = 10076,
+     KW_FLUSH_TIMEOUT = 10077,
+     KW_LOG_MSG_SIZE = 10078,
+     KW_FILE_TEMPLATE = 10079,
+     KW_PROTO_TEMPLATE = 10080,
+     KW_MARK_MODE = 10081,
+     KW_CHAIN_HOSTNAMES = 10090,
+     KW_NORMALIZE_HOSTNAMES = 10091,
+     KW_KEEP_HOSTNAME = 10092,
+     KW_CHECK_HOSTNAME = 10093,
+     KW_BAD_HOSTNAME = 10094,
+     KW_KEEP_TIMESTAMP = 10100,
+     KW_USE_DNS = 10110,
+     KW_USE_FQDN = 10111,
+     KW_CUSTOM_DOMAIN = 10112,
+     KW_DNS_CACHE = 10120,
+     KW_DNS_CACHE_SIZE = 10121,
+     KW_DNS_CACHE_EXPIRE = 10130,
+     KW_DNS_CACHE_EXPIRE_FAILED = 10131,
+     KW_DNS_CACHE_HOSTS = 10132,
+     KW_PERSIST_ONLY = 10140,
+     KW_USE_RCPTID = 10141,
+     KW_TZ_CONVERT = 10150,
+     KW_TS_FORMAT = 10151,
+     KW_FRAC_DIGITS = 10152,
+     KW_LOG_FIFO_SIZE = 10160,
+     KW_LOG_FETCH_LIMIT = 10162,
+     KW_LOG_IW_SIZE = 10163,
+     KW_LOG_PREFIX = 10164,
+     KW_PROGRAM_OVERRIDE = 10165,
+     KW_HOST_OVERRIDE = 10166,
+     KW_THROTTLE = 10170,
+     KW_THREADED = 10171,
+     KW_FLAGS = 10190,
+     KW_PAD_SIZE = 10200,
+     KW_TIME_ZONE = 10201,
+     KW_RECV_TIME_ZONE = 10202,
+     KW_SEND_TIME_ZONE = 10203,
+     KW_LOCAL_TIME_ZONE = 10204,
+     KW_FORMAT = 10205,
+     KW_TIME_REOPEN = 10210,
+     KW_TIME_REAP = 10211,
+     KW_TIME_SLEEP = 10212,
+     KW_TMPL_ESCAPE = 10220,
+     KW_OPTIONAL = 10230,
+     KW_CREATE_DIRS = 10240,
+     KW_OWNER = 10250,
+     KW_GROUP = 10251,
+     KW_PERM = 10252,
+     KW_DIR_OWNER = 10260,
+     KW_DIR_GROUP = 10261,
+     KW_DIR_PERM = 10262,
+     KW_TEMPLATE = 10270,
+     KW_TEMPLATE_ESCAPE = 10271,
+     KW_DEFAULT_FACILITY = 10300,
+     KW_DEFAULT_LEVEL = 10301,
+     KW_PORT = 10323,
+     KW_USE_TIME_RECVD = 10340,
+     KW_FACILITY = 10350,
+     KW_LEVEL = 10351,
+     KW_HOST = 10352,
+     KW_MATCH = 10353,
+     KW_MESSAGE = 10354,
+     KW_NETMASK = 10355,
+     KW_TAGS = 10356,
+     KW_VALUE = 10361,
+     KW_REWRITE = 10370,
+     KW_SET = 10371,
+     KW_SUBST = 10372,
+     KW_YES = 10380,
+     KW_NO = 10381,
+     KW_IFDEF = 10410,
+     KW_ENDIF = 10411,
+     LL_DOTDOT = 10420,
+     LL_IDENTIFIER = 10421,
+     LL_NUMBER = 10422,
+     LL_FLOAT = 10423,
+     LL_STRING = 10424,
+     LL_TOKEN = 10425,
+     LL_BLOCK = 10426,
+     LL_PRAGMA = 10427,
+     LL_EOL = 10428,
+     LL_ERROR = 10429,
+     KW_VALUE_PAIRS = 10500,
+     KW_SELECT = 10501,
+     KW_EXCLUDE = 10502,
+     KW_PAIR = 10503,
+     KW_KEY = 10504,
+     KW_SCOPE = 10505,
+     KW_SHIFT = 10506,
+     KW_REKEY = 10507,
+     KW_ADD_PREFIX = 10508,
+     KW_REPLACE_PREFIX = 10509,
+     KW_ON_ERROR = 10510,
+     KW_RETRIES = 10511
+   };
 #endif
 /* Tokens.  */
 #define LL_CONTEXT_ROOT 1
@@ -277,13 +283,14 @@ extern struct _ValuePairsTransformSet *last_vp_transset;
 #define KW_MARK_FREQ 10071
 #define KW_STATS_FREQ 10072
 #define KW_STATS_LEVEL 10073
-#define KW_FLUSH_LINES 10074
-#define KW_SUPPRESS 10075
-#define KW_FLUSH_TIMEOUT 10076
-#define KW_LOG_MSG_SIZE 10077
-#define KW_FILE_TEMPLATE 10078
-#define KW_PROTO_TEMPLATE 10079
-#define KW_MARK_MODE 10080
+#define KW_STATS_LIFETIME 10074
+#define KW_FLUSH_LINES 10075
+#define KW_SUPPRESS 10076
+#define KW_FLUSH_TIMEOUT 10077
+#define KW_LOG_MSG_SIZE 10078
+#define KW_FILE_TEMPLATE 10079
+#define KW_PROTO_TEMPLATE 10080
+#define KW_MARK_MODE 10081
 #define KW_CHAIN_HOSTNAMES 10090
 #define KW_NORMALIZE_HOSTNAMES 10091
 #define KW_KEEP_HOSTNAME 10092
@@ -292,12 +299,14 @@ extern struct _ValuePairsTransformSet *last_vp_transset;
 #define KW_KEEP_TIMESTAMP 10100
 #define KW_USE_DNS 10110
 #define KW_USE_FQDN 10111
+#define KW_CUSTOM_DOMAIN 10112
 #define KW_DNS_CACHE 10120
 #define KW_DNS_CACHE_SIZE 10121
 #define KW_DNS_CACHE_EXPIRE 10130
 #define KW_DNS_CACHE_EXPIRE_FAILED 10131
 #define KW_DNS_CACHE_HOSTS 10132
 #define KW_PERSIST_ONLY 10140
+#define KW_USE_RCPTID 10141
 #define KW_TZ_CONVERT 10150
 #define KW_TS_FORMAT 10151
 #define KW_FRAC_DIGITS 10152
@@ -370,25 +379,31 @@ extern struct _ValuePairsTransformSet *last_vp_transset;
 #define KW_ADD_PREFIX 10508
 #define KW_REPLACE_PREFIX 10509
 #define KW_ON_ERROR 10510
+#define KW_RETRIES 10511
+
+
+
+
+#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+
+# define yystype YYSTYPE /* obsolescent; will be withdrawn */
+# define YYSTYPE_IS_DECLARED 1
+#endif
+
 
-/* Value type.  */
 
-/* Location type.  */
 #if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
-typedef struct YYLTYPE YYLTYPE;
-struct YYLTYPE
+typedef struct YYLTYPE
 {
   int first_line;
   int first_column;
   int last_line;
   int last_column;
-};
+} YYLTYPE;
+# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
 # define YYLTYPE_IS_DECLARED 1
 # define YYLTYPE_IS_TRIVIAL 1
 #endif
 
 
 
-int main_parse (CfgLexer *lexer, gpointer *dummy, gpointer arg);
-
-#endif /* !YY_MAIN_LIB_CFG_GRAMMAR_H_INCLUDED  */
